@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2012, 2014-2018 Free Software Foundation, Inc.
+   Copyright (C) 2011-2023 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -85,8 +85,6 @@ int mu_msgset_parse_imap (mu_msgset_t set, int mode, const char *s,
 int mu_stream_msgset_format (mu_stream_t str,
 			     struct mu_msgset_format const *fmt,
 			     mu_msgset_t mset);
-int mu_msgset_print (mu_stream_t str, mu_msgset_t msgset)
-  MU_DEPRECATED;
 
 static inline int
 mu_msgset_imap_print (mu_stream_t str, mu_msgset_t mset)
